O.Brien_test: O'Brien's Test of Homogeneity of Variances

View source: R/O.Brien_test.R

O.Brien_testR Documentation

O'Brien's Test of Homogeneity of Variances

Description

Performs O'Brien's test to assess the null hypothesis that the variances are equal across all groups (samples) defined by the independent variable.

Usage

O.Brien_test(
  data,
  formula,
  alpha = 0.05,
  silent = FALSE,
  summary = FALSE,
  misc = FALSE,
  transform = function(x) (x - stats::median(x))^2
)

Arguments

data

A data frame containing the variables specified in the formula.

formula

A formula of the form DV ~ IV, where DV is the dependent (response) variable and IV is the independent (grouping) variable.

alpha

A numeric value specifying the significance level. Must be between 0 and 1. Default is 0.05.

silent

A logical value. If FALSE (default), results are printed to the console. If TRUE, no output is printed.

summary

A logical value (default: FALSE). If TRUE, a summary table for the input data is returned.

misc

A logical value. If FALSE (default), only essential parameters are returned. If TRUE, additional auxiliary parameters are included in the output.

transform

A function used to transform the response variable into deviations from a specified location measure.

Details

transform: The concept is similar to ANOVA procedure (transform the response variable to residuals before analysis). Possible transformation are:

  • y' = |yi - ybar|

  • y' = (yi - ybar) ^ 2 (default)

  • y' = ln((yi - ybar) ^ 2)

  • y' = sqrt(|yi - ybar|)

The ybar could be either mean, median (default), or trimmed-mean.

Note: This test is often regarded as conservative and may have relatively low power to detect heteroscedasticity. The Levene and Brown-Forsythe tests are generally preferred for assessing the homogeneity of variances.

Value

A list containing the test statistics, p-value, degrees of freedom, and optionally a summary table and/or auxiliary parameters, depending on the values of summary and misc.

References

O’Brien, R. G. (1981). A simple test for variance effects in experimental designs. Psychological Bulletin, 89(3), 570–574. https://doi.org/10.1037/0033-2909.89.3.570

See Also

[Brown_Forsythe_test][Levene_test][O.Neill_Mathews_test]

Examples

df0 <- CYCB1[[1]]
out <- O.Brien_test(df0, cells ~ grp)
boxplot(cells ~ grp, df0, horizontal = TRUE)
points(x = df0$cells, y = jitter(as.numeric(df0$grp), amount = 0.15))

varequal documentation built on Sept. 5, 2026, 5:08 p.m.